import { BasicColumn, FormSchema } from '@/components/Table';

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
    slots: { customRender: 'name' },
  },
  {
    title: '场景',
    dataIndex: 'scene',
    width: 150,
  },
  {
    title: '权属工作组',
    dataIndex: 'workgroup',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateTime',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 100,
  },
  {
    title: '发布状态',
    dataIndex: 'releaseStatus',
    width: 120,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 5 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
  {
    field: 'releaseStatus',
    label: ' ',
    component: 'Select',
    colProps: { span: 5 },
    componentProps: {
      placeholder: '发布状态',
      options: [
        { label: '未发布', value: '未发布' },
        { label: '已发布', value: '已发布' },
        { label: '审核中', value: '审核中' },
        { label: '已下线', value: '已下线' },
      ],
    },
  },
];

export const MoveFormSchema: any[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      // border: 'none',
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];

export const formSchemaNewFolder: any = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },

  {
    field: 'name',
    label: '文件夹名称',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件夹名称',
    },
  },
  // {
  //   field: 'fileType',
  //   label: '权限模式',
  //   component: 'RadioGroup',
  //   defaultValue: '本级定义',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     options: [
  //       { label: '本级定义', value: '本级定义' },
  //       { label: '资源自定义', value: '资源自定义' },
  //     ],
  //     placeholder: '输入描述',
  //   },
  // },
  // {
  //   field: 'group',
  //   label: '权属工作组',
  //   component: 'Select',
  //   defaultValue: '默认工作组',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     placeholder: '输入描述',
  //     options: [{ label: '默认工作组', value: '默认工作组' }],
  //   },
  // },
];

export const importFormSchema: any[] = [
  {
    label: '导入任务版本',
    field: 'importVersionAlert',
    slot: 'importVersionAlert',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'importType',
    label: '导入类型',
    component: 'RadioGroup',
    required: true,
    colProps: { lg: 24, md: 24 },
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '同集群导入', value: '1' },
        { label: '其他集群导入', value: '2' },
      ],
    },
  },
  {
    field: 'importOptionsAlert',
    slot: 'importOptionsAlert',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'deptId',
    label: '导入至',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'deptName',
        value: 'businessId',
      },
      treeData: [
        {
          deptName: '数据加载',
          businessId: '1',
          children: [
            {
              deptName: '个人工作区',
              businessId: '11',
              children: [
                {
                  deptName: '图标验收',
                  businessId: '111',
                },
              ],
            },
            {
              deptName: '共享工作区',
              businessId: '12',
              children: [
                {
                  deptName: '学生成绩',
                  businessId: '122',
                },
              ],
            },
          ],
        },
      ],
    },
    required: true,
  },
  {
    field: 'fileMethods',
    label: '导入文件选择',
    slot: 'fileMethods',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fileRename',
    label: '文件重名',
    component: 'RadioGroup',
    required: true,
    defaultValue: '3',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '全部放弃', value: '1' },
        { label: '全部替换', value: '2' },
        { label: '自动重命名', value: '3' },
      ],
    },
  },
];

export const NewFieldRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'newFieldRuleAlert',
    slot: 'newFieldRuleAlert',
  },
  {
    field: 'newFieldName',
    label: '新增字段名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'newFieldType',
    label: '新增字段类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'int', value: 'int' },
        { label: 'bigint', value: 'bigint' },
        { label: 'decimal', value: 'decimal' },
        { label: 'varchar', value: 'varchar' },
        { label: 'string', value: 'string' },
        { label: 'timestamp', value: 'timestamp' },
      ],
    },
    required: true,
  },
  {
    field: 'fieldExpression',
    label: '字段表达式',
    component: 'Input',
    required: true,
  },
];

export const FieldTypeMappingRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'newFieldRuleAlert',
    slot: 'newFieldRuleAlert',
  },
  {
    field: 'sourceFieldType',
    label: '源字段类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'int', value: 'int' },
        { label: 'bigint', value: 'bigint' },
        { label: 'decimal', value: 'decimal' },
        { label: 'varchar', value: 'varchar' },
        { label: 'string', value: 'string' },
        { label: 'timestamp', value: 'timestamp' },
      ],
    },
    required: true,
  },
  {
    field: 'targetFieldType',
    label: '目标字段类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'int', value: 'int' },
        { label: 'bigint', value: 'bigint' },
        { label: 'decimal', value: 'decimal' },
        { label: 'varchar', value: 'varchar' },
        { label: 'string', value: 'string' },
        { label: 'timestamp', value: 'timestamp' },
      ],
    },
    required: true,
  },
];

export const DataTransformationRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'selectiveDataTable',
    label: '选择数据表',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'table_1', value: 'table_1' },
        { label: 'table_2', value: 'table_2' },
        { label: 'table_3', value: 'table_3' },
        { label: 'table_4', value: 'table_4' },
      ],
    },
    required: true,
  },
  {
    field: 'conversionResultWriting',
    label: '转换结果写入',
    component: 'RadioGroup',
    defaultValue: '覆盖已有字段',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.conversionResultWriting === '覆盖已有字段';
        formActionType.updateSchema([{ field: 'selectExistingField', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'newFieldName', ifShow: !flag }]);
        formActionType.updateSchema([{ field: 'newFieldType', ifShow: !flag }]);
      },
      options: [
        { label: '覆盖已有字段', value: '覆盖已有字段' },
        { label: '写入新增字段', value: '写入新增字段' },
      ],
    }),
  },
  {
    field: 'selectExistingField',
    label: '选择已有字段',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'total_amount', value: 'total_amount' },
        { label: 'payment_id', value: 'payment_id' },
        { label: 'position', value: 'position' },
        { label: 'employee_id', value: 'employee_id' },
      ],
    },
    required: true,
    ifShow: true,
  },
  {
    field: 'newFieldName',
    label: '新增字段名称',
    component: 'Input',
    required: true,
    ifShow: false,
  },
  {
    field: 'newFieldType',
    label: '新增字段类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'int', value: 'int' },
        { label: 'bigint', value: 'bigint' },
        { label: 'decimal', value: 'decimal' },
        { label: 'varchar', value: 'varchar' },
        { label: 'string', value: 'string' },
        { label: 'timestamp', value: 'timestamp' },
      ],
    },
    required: true,
    ifShow: false,
  },
  {
    field: 'conversionRule',
    label: '转换规则',
    component: 'RadioGroup',
    defaultValue: '配置规则',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.conversionRule === '自定义';
        formActionType.updateSchema([{ field: 'customRule', ifShow: flag }]);
      },
      options: [
        { label: '配置规则', value: '配置规则' },
        { label: '自定义', value: '自定义' },
      ],
    }),
  },
  {
    field: 'customRule',
    label: '自定义规则',
    component: 'InputTextArea',
    ifShow: false,
  },
];

export const FieldNameMappingRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'regularExpressionAlert',
    slot: 'regularExpressionAlert',
  },
  {
    field: 'regularExpression',
    label: '正则表达式',
    component: 'Checkbox',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.regularExpression;
        formActionType.updateSchema([{ field: 'sourceDatabaseNameExpression', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'targetLibraryNameExpression', ifShow: flag }]);
      },
    }),
  },
  {
    field: 'sourceDatabaseNameExpression',
    label: '源库名表达式',
    component: 'Input',
    defaultValue: '^(.*)$',
    required: true,
    ifShow: false,
  },
  {
    field: 'targetLibraryNameExpression',
    label: '目标库名表达式',
    defaultValue: 'test_$1_obs',
    component: 'Input',
    ifShow: false,
  },
  {
    field: 'addPrefix',
    label: '添加前缀',
    component: 'Checkbox',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.addPrefix;
        formActionType.updateSchema([{ field: 'prefixExpression', ifShow: flag }]);
      },
    }),
  },
  {
    field: 'prefixExpression',
    label: '表达式',
    component: 'Input',
    defaultValue: 'test_',
    required: true,
    ifShow: false,
  },
  {
    field: 'addSuffixation',
    label: '添加后缀',
    component: 'Checkbox',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.addSuffixation;
        formActionType.updateSchema([{ field: 'suffixationExpression', ifShow: flag }]);
      },
    }),
  },
  {
    field: 'suffixationExpression',
    label: '表达式',
    component: 'Input',
    defaultValue: '_obs',
    required: true,
    ifShow: false,
  },
  {
    field: 'reviewButton',
    label: '',
    slot: 'reviewButton',
  },
  {
    field: 'reviewTable',
    label: '',
    slot: 'reviewTable',
  },
];

export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件名称',
    },
    colProps: { span: 8 },
  },
];

export const BatchScaleNameMappingFormSchema: FormSchema[] = [
  {
    field: 'regularExpression',
    label: '正则表达式',
    component: 'Checkbox',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.regularExpression;
        formActionType.updateSchema([{ field: 'sourceDatabaseNameExpression', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'targetLibraryNameExpression', ifShow: flag }]);
      },
    }),
  },
  {
    field: 'regularExpressionAlert',
    slot: 'regularExpressionAlert',
  },
  {
    field: 'sourceDatabaseNameExpression',
    label: '源库名表达式',
    component: 'Input',
    defaultValue: '^(.*)$',
    required: true,
    ifShow: false,
  },
  {
    field: 'targetLibraryNameExpression',
    label: '目标库名表达式',
    defaultValue: 'test_$1_obs',
    component: 'Input',
    ifShow: false,
  },
  {
    field: 'addPrefix',
    label: '添加前缀',
    component: 'Checkbox',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.addPrefix;
        formActionType.updateSchema([{ field: 'prefixExpression', ifShow: flag }]);
      },
    }),
  },
  {
    field: 'prefixExpression',
    label: '表达式',
    component: 'Input',
    defaultValue: 'test_',
    required: true,
    ifShow: false,
  },
  {
    field: 'addSuffixation',
    label: '添加后缀',
    component: 'Checkbox',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.addSuffixation;
        formActionType.updateSchema([{ field: 'suffixationExpression', ifShow: flag }]);
      },
    }),
  },
  {
    field: 'suffixationExpression',
    label: '表达式',
    component: 'Input',
    defaultValue: '_obs',
    required: true,
    ifShow: false,
  },
  {
    field: 'reviewButton',
    label: '',
    slot: 'reviewButton',
  },
  {
    field: 'reviewTable',
    label: '',
    slot: 'reviewTable',
  },
];

export const SingleTableFieldMappingRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'selectiveDataTable',
    label: '源表名',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'table_1', value: 'table_1' },
        { label: 'table_2', value: 'table_2' },
        { label: 'table_3', value: 'table_3' },
        { label: 'table_4', value: 'table_4' },
      ],
    },
    required: true,
  },
  {
    field: 'mappingTable',
    slot: 'mappingTable',
  },
];

export const PartitionedDataProcessingFormSchema: FormSchema[] = [
  {
    field: 'partitionType',
    label: '分区类型',
    component: 'RadioGroup',
    defaultValue: '单值分区',
    componentProps: {
      options: [{ label: '单值分区', value: '单值分区' }],
    },
  },
  {
    field: 'overwritesTheSingleValuePartitionRawData',
    label: '覆盖单值分区原数据',
    component: 'Switch',
    defaultValue: false,
  },
  {
    field: 'partitionKeyName',
    label: '分区键名',
    component: 'Input',
  },
  {
    field: 'partitionKeyValue',
    label: '分区键值',
    component: 'Input',
  },
];

export const ClearConfigurationFormSchema: FormSchema[] = [
  {
    field: 'cleaningCondition',
    label: '清理条件',
    component: 'BasicTitle',
  },
  {
    field: 'cleaningConditionAlert',
    slot: 'cleaningConditionAlert',
  },
  {
    field: 'cleaningConfiguration',
    slot: 'cleaningConfiguration',
  },
];

export const recommendColumns: BasicColumn[] = [
  {
    title: '参数名',
    dataIndex: 'name',
    editable: true,
    edit: true,
    width: 120,
  },
  {
    title: '表达式',
    dataIndex: 'expression',
    editable: true,
    edit: true,
    width: 120,
  },
  {
    title: '参数类型',
    dataIndex: 'type',
    editable: true,
    edit: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        { label: '写入端引擎参数', value: '1' },
        { label: '服务参数', value: '2' },
        { label: '普通参数', value: '3' },
      ],
    },
    width: 120,
  },
];

export const globalOptionsSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
    defaultValue: 'TDT1',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'remark',
    label: '描述',
    component: 'InputTextArea',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'period',
    label: '调度周期',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'Cron表达式', value: '1' },
        { label: '每天一次', value: '2' },
        { label: '无周期', value: '3' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'cron',
    label: 'Cron表达式',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.period === '1',
  },
  {
    field: 'periodTime',
    label: '调度时间',
    component: 'TimePicker',
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.period === '2',
  },
  {
    field: 'timeoutType',
    component: 'Checkbox',
    label: '超时取消',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.timeoutType;
        formActionType.updateSchema([{ field: 'minute', ifShow: flag }]);
      },
    }),
    renderComponentContent: '开启',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'minute',
    label: '分钟',
    component: 'InputNumber',
    componentProps: {
      min: 0,
      max: 1000,
    },
    ifShow: false,
    labelWidth: 40,
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'DDLOption',
    component: 'Checkbox',
    label: 'DDL变化策略配置',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.DDLOption;
        formActionType.updateSchema([{ field: 'isDeleteTable', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'isDeleteTableField', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'addTableField', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'changeTableField', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'globalOptionsAlert', ifShow: flag }]);
      },
    }),
    renderComponentContent: '开启',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'globalOptionsAlert',
    slot: 'globalOptionsAlert',
    ifShow: false,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'isDeleteTable',
    label: '源端数据表被删除',
    component: 'RadioGroup',
    defaultValue: '1',
    ifShow: false,
    componentProps: {
      options: [{ label: '取消运行子任务', value: '1' }],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'isDeleteTableField',
    label: '源端数据表字段被删除',
    component: 'RadioGroup',
    defaultValue: '1',
    ifShow: false,
    componentProps: {
      options: [
        { label: '取消运行子任务', value: '1' },
        { label: '取消运行子任务并不能影响任务结果', value: '2' },
        { label: '空值填充', value: '3' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'addTableField',
    label: '源端数据表新增字段',
    component: 'RadioGroup',
    defaultValue: '1',
    ifShow: false,
    componentProps: {
      options: [
        { label: '取消运行子任务', value: '1' },
        { label: '取消运行子任务并不能影响任务结果', value: '2' },
        { label: '忽略新增字段', value: '3' },
        { label: '自动更新', value: '4' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'changeTableField',
    label: '源端数据表字段或类型变更',
    component: 'RadioGroup',
    defaultValue: '1',
    ifShow: false,
    componentProps: {
      options: [{ label: '取消运行子任务', value: '1' }],
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const saveSchema: FormSchema[] = [
  {
    field: 'remark',
    label: '版本变更描述',
    component: 'InputTextArea',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
];
export const versionManageColumns: BasicColumn[] = [
  {
    title: '版本名称',
    dataIndex: 'name',
    width: 100,
  },
  {
    title: '提交人',
    dataIndex: 'user',
    width: 100,
  },
  {
    title: '提交时间',
    dataIndex: 'date',
    width: 140,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 140,
  },
];
export const runOptionsColumns: BasicColumn[] = [
  {
    title: '参数名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '参数类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '参数值',
    dataIndex: 'data',
    width: 120,
    edit: true,
    editable: true,
  },
];
export const searchEditFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    componentProps: {
      placeholder: '搜索名称',
    },
  },
];
