import { FormSchema } from '@/components/Form';
import { BasicColumn } from '@/components/Table';

export const isCustomSQLColumns: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'fieldName',
  },
  {
    title: '类型',
    dataIndex: 'fieldType',
  },
];

export const getMetadataColumns: BasicColumn[] = [
  {
    title: '表名',
    dataIndex: 'tableName',
  },
];

export const configurationColumns: BasicColumn[] = [
  {
    title: '源端',
    dataIndex: 'sourceTableName',
  },
  {
    title: '目标端',
    dataIndex: 'targetTableName',
    edit: true,
  },
  {
    title: '配置方式',
    dataIndex: 'configurationMode',
    slots: { customRender: 'configurationMode' },
    width: 120,
  },
  {
    title: '分区数据配置',
    dataIndex: 'partitionQuantityConfiguration',
    slots: { customRender: 'partitionQuantityConfiguration' },
    width: 90,
  },
  {
    title: '清理配置',
    dataIndex: 'clearConfiguration',
    slots: { customRender: 'clearConfiguration' },
    width: 90,
  },
];
export const noConfigurationColumns: BasicColumn[] = [
  {
    title: '源端',
    dataIndex: 'sourceTableName',
  },
  {
    title: '目标端',
    dataIndex: 'targetTableName',
    edit: true,
  },
  {
    title: '分区数据配置',
    dataIndex: 'partitionQuantityConfiguration',
    slots: { customRender: 'partitionQuantityConfiguration' },
    width: 90,
  },
  {
    title: '清理配置',
    dataIndex: 'clearConfiguration',
    slots: { customRender: 'clearConfiguration' },
    width: 90,
  },
];

export const partitionKeyColumns: BasicColumn[] = [
  {
    title: '分区键',
    dataIndex: 'fieldName',
    editComponent: 'Input',
    width: 500,
    editRow: true,
  },
  {
    title: '分区类型',
    dataIndex: 'fieldType',
    editComponent: 'Select',
    editRow: true,
    editComponentProps: {
      options: [
        { label: 'STRING', value: 'STRING' },
        { label: 'INT', value: 'INT' },
        { label: 'DATETIME', value: 'DATETIME' },
        { label: 'CHAR', value: 'CHAR' },
        { label: 'BOOLEAN', value: 'BOOLEAN' },
      ],
    }
  },
];

export const partitionRangeColumns: BasicColumn[] = [
  {
    title: '分区名',
    dataIndex: 'name',
    editComponent: 'Input',
    editRow: true,
  },
  {
    title: '分区值',
    dataIndex: 'value',
    editComponent: 'Input',
    editRow: true,
  },
];

export const otherConfigurationColumns: BasicColumn[] = [
  {
    title: '其他配置类型',
    dataIndex: 'otherConfigurationType',
    editComponent: 'Select',
    editRow: true,
    width: 120,
    editComponentProps: {
      options: [
        { label: '表注释', value: '表注释' },
        { label: '表别名', value: '表别名' },
      ],
    },
  },
  {
    title: '其他配置内容',
    editRow: true,
    dataIndex: 'otherConfigurationContent',
    editComponent: 'Input',
  },
];

export const notCustomSQLColumns: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'fieldName',
  },
  {
    title: '类型',
    dataIndex: 'fieldType',
  },
  {
    title: '数据转换',
    dataIndex: 'dataConversion',
    slots: { customRender: 'dataConversion' },
  },
];

export const mappingRuleConfigurationColumns: BasicColumn[] = [
  {
    title: '规则名称',
    dataIndex: 'ruleName',
    width: 200,
  },
  {
    title: '规则内容',
    dataIndex: 'ruleContent',
  },
  {
    title: '执行顺序',
    width: 100,
    dataIndex: 'executionSequence',
    slots: { customRender: 'executionSequence' },
  },
];

export const fieldNameMappingRuleColumns: BasicColumn[] = [
  {
    title: '源字段名',
    dataIndex: 'fieldName',
    labelWidth: 160,
  },
  {
    title: '目标字段名',
    dataIndex: 'targetFieldName',
  },
];

export const batchScaleNameMappingColumns: BasicColumn[] = [
  {
    title: '源表名',
    dataIndex: 'fieldName',
    labelWidth: 160,
  },
  {
    title: '目标表名',
    dataIndex: 'targetFieldName',
  },
];

export const singleSourceFieldNameMappingRuleColumns: BasicColumn[] = [
  {
    title: '字段名',
    dataIndex: 'fieldName',
  },
  {
    title: '字段类型',
    dataIndex: 'fieldType',
  },
  {
    title: '注释',
    dataIndex: 'annotation',
  },
];

export const singleGoalFieldNameMappingRuleColumns: BasicColumn[] = [
  {
    title: '字段名',
    dataIndex: 'targetFieldName',
    edit: true,
  },
  {
    title: '字段类型',
    dataIndex: 'fieldType',
    edit: true,
  },
  {
    title: '注释',
    dataIndex: 'annotation',
  },
];

export const tabularPresentationColumns: BasicColumn[] = [
  {
    title: '源表名',
    dataIndex: 'sourceTable',
  },
  {
    title: '目标表名',
    dataIndex: 'targetTable',
  },
  {
    title: '表类型',
    width: 90,
    dataIndex: 'tableType',
  },
  {
    title: '分区类型',
    width: 90,
    dataIndex: 'areaType',
  },
  {
    title: '分区键',
    width: 100,
    dataIndex: 'partitionKey',
  },
  {
    title: '调试结果',
    dataIndex: 'debuggingResult',
  },
];

export const compareColumns: BasicColumn[] = [
  {
    title: '源列名',
    dataIndex: 'sourceColumnName',
    slots: { customRender: 'sourceColumnName' },
  },
  {
    title: '目标列名',
    dataIndex: 'targetColumnName',
    slots: { customRender: 'targetColumnName' },
  },
];

export const tabularPresentationSearchFormSchema: FormSchema[] = [
  {
    field: 'tableName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入表名',
    },
  },
];

export const compareSearchFormSchema: FormSchema[] = [
  {
    field: 'columnName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入列名',
    },
  },
];

export const tableListSearchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
];
